@@ -12,14 +12,16 @@ Graph::~Graph()
 {
 }
 /********************************************************************************************/
-void Graph::Init(Pp *pp0, int *gtype0, double *par0, double *prepR0, int *doDists0, double *preDists, int *toroidal0, int *inc0, int *dbg0)
+void Graph::Init(Pp *pp0, int *gtype0, double *par0, double *prepR0, int *doDists0,
+		double *preDists, int *toroidal0, int *inc0, double *wMatrix, int *dbg0)
 {
 	int typein,i,j;
-	if(*dbg0)printf("intializing graph-object... ");
+	if(*dbg0)Rprintf("intializing graph-object... ");
 
 	pp = pp0;
 	par=par0;
 	prepR=prepR0;
+	preEdges = 0;
 	opar = *par;
 	oldpar = &opar;
 	doDists=doDists0;
@@ -30,6 +32,14 @@ void Graph::Init(Pp *pp0, int *gtype0, double *par0, double *prepR0, int *doDist
 	mdeg = 0.0;
 	pp->setToroidal(toroidal0);
 	typeIncluded.clear();
+	weightMatrix = wMatrix;
+
+	if(weightMatrix[0]<0)getTypeToTypeWeightp = &Graph::getTypeToTypeWeight_all1; // if no weights given
+	else{
+		if(*dbg)Rprintf("Type-to-Type weight matrix received.\n");
+		getTypeToTypeWeightp = &Graph::getTypeToTypeWeight_weighted; // weights given
+	}
+
 	for(i=0; i< pp->getNtypes(); i++)//need to ignore some types based on the inclusion vector
 	{
 		typein=0;
@@ -44,17 +54,17 @@ void Graph::Init(Pp *pp0, int *gtype0, double *par0, double *prepR0, int *doDist
 
 	if(preDists[0]>=0)
 	{
-		if(*dbg)printf("Setting precalculated distances...");
+		if(*dbg)Rprintf("Setting precalculated distances...");
 		pp->setDists(preDists);
-		if(*dbg)printf("ok. ");
+		if(*dbg)Rprintf("ok. ");
 	}
 	else if(*doDists)  // precalculate distance triangle
 	{
-		if(*dbg)printf("Precalculating distances...");
+		if(*dbg)Rprintf("Precalculating distances...");
 		pp->calcDists();
-		if(*dbg)printf("ok. ");
+		if(*dbg)Rprintf("ok. ");
 	}
-	if(*dbg)printf(" done.\n");
+	if(*dbg)Rprintf(" done.\n");
 
 }
 
@@ -65,12 +75,16 @@ void Graph::setNodelist(std::vector<std::vector<int> > *nodelist_new)
 	nodelist.clear();nodelist.resize(0);
 	for(i=0;i<(int)nodelist_new->size();i++)
 		nodelist.push_back(nodelist_new->at(i));
+	preEdges = 1;
 }
 /********************************************************************************************/
 void Graph::setNodelist(SEXP prepGraph)
 {
+	if(*dbg)Rprintf("setting precalculated edges...");
 	nodelist.clear();nodelist.resize(0);
 	VectsxpToVector(getListElement(prepGraph,"edges"), nodelist);
+	preEdges = 1;
+	if(*dbg)Rprintf("ok.");
 }
 /********************************************************************************************/
 SEXP Graph::toSEXP()
@@ -94,6 +108,7 @@ SEXP Graph::toSEXP()
 		this->nodelist[i].clear();
 		SET_VECTOR_ELT(graph, i, *node);
 		UNPROTECT(1);
+		delete node;
 	}
 	UNPROTECT(1);
 	return graph;
@@ -143,6 +158,20 @@ void Graph::addNew(int i, int j)
 		nodelist.at(i).push_back(j);
 }
 /********************************************************************************************/
+/********************************************************************************************/
+// Weight matrix functions
+double Graph::getTypeToTypeWeight(int *t1, int *t2){
+	return (this->*getTypeToTypeWeightp)(t1,t2);
+}
+// if truly weighted
+double Graph::getTypeToTypeWeight_weighted(int *t1, int *t2){
+	return weightMatrix[(*t2-1)*pp->getNtypes()+(*t1-1)];
+}
+// otherwise
+double Graph::getTypeToTypeWeight_all1(int *t1, int *t2){
+	return 1;
+}
+/********************************************************************************************/
 //The graph methods
 /********************************************************************************************/
 void Graph::sg_calc()
@@ -150,21 +179,22 @@ void Graph::sg_calc()
 	// preprocess if requested
 	if(prepR[0]>0 && *oldpar<= *par )
 	{
-		if(*dbg)printf("Preprocessing[");
+		if(*dbg)Rprintf("Preprocessing[");
 		this->sg_geometric(prepR);
-		if(*dbg)printf("] ok.\n ");
+		preEdges = 1;
+		if(*dbg)Rprintf("] ok.\n ");
 	}
 	//start the calculation
 	if(*gtype==0) //geometric
 	{
-		if(*oldpar > *par)
+		if(preEdges)
 			this->sg_shrink_geometric(par);
 		else
 			this->sg_geometric();
 	}
 	else if(*gtype==1) //knn
 	{
-		if(*oldpar > *par)
+		if(preEdges)
 			this->sg_shrink_knn();
 		else
 			this->sg_knn();
@@ -179,6 +209,8 @@ void Graph::sg_calc()
 	else if(*gtype==9) this->sg_RNG();
 	else if(*gtype==10) this->sg_CCC();
 	else if(*gtype==11) this->sg_STIR();
+	else if(*gtype==12) this->sg_big_geometric();
+	preEdges = 1;
 }
 
 /********************************************************************************************/
@@ -189,7 +221,7 @@ void Graph::sg_geometric()
 
 void Graph::sg_geometric(double *R)
 {
-	if(*dbg)printf("Geometric (R=%f):",*R);
+	if(*dbg)Rprintf("Geometric (R=%f):",*R);
 	int i,j;
 	double dist;
 	for(i=0;i<(pp->size()-1);i++)
@@ -202,12 +234,32 @@ void Graph::sg_geometric(double *R)
 			}
 		}
 	mdeg = this->pp->lambda*PI*(*R)*(*R);
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" Ok.");
+}
+
+void Graph::sg_big_geometric()
+{
+	if(*dbg)Rprintf("Big geometric (R=%f):",*par);
+	int i,j;
+	double dist;
+	for(i=0;i<pp->size();i++)
+		if(inc[i])
+			for(j=0;j<pp->size();j++)
+				if(i!=j)
+				{
+					dist = pp->getDist(&i, &j);
+					if(dist<*par){
+						nodelist[i].push_back(j+1);
+					}
+				}
+	mdeg = this->pp->lambda*PI*(*par)*(*par);
+	if(*dbg)Rprintf(" Ok.");
+	*gtype = 0;
 }
 
 void Graph::sg_shrink_geometric(double *R)
 {
-	if(*dbg)printf("Geometric (R=%f) (shrinking):",*R);
+	if(*dbg)Rprintf("Geometric (R=%f) (shrinking):",*R);
 	int i,j,j0;
 	double dist;
 	std::vector<int> *node;
@@ -225,14 +277,14 @@ void Graph::sg_shrink_geometric(double *R)
 			nodelist[i].clear();nodelist[i].resize(0);
 			for (j = 0; j < (int)node->size(); ++j) this->nodelist[i].push_back(node->at(j));
 			delete node;
-		}
+	}
 	mdeg = this->pp->lambda*PI*(*R)*(*R);
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" ok.");
 }
 /********************************************************************************************/
 void Graph::sg_mass_geometric()
 {
-	if(*dbg)printf("Mass-geometric:");
+	if(*dbg)Rprintf("Mass-geometric:");
 	int i,j;
 	double dist;
 	for(i=0;i<pp->size();i++)
@@ -247,19 +299,19 @@ void Graph::sg_mass_geometric()
 				}
 			}
 		}
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" Ok.");
 }
 /********************************************************************************************/
 void Graph::sg_knn()
 {
 
-	int i,j,l,*k,kk, mik;
+	int i,j,l,*k,kk, mink;
 	kk = (int) par[0];
 	k = &kk;
 	std::vector<int> *node;
-	if(*prepR==0)// if not preprocessed
+	if(preEdges==0)// if not preprocessed
 	{
-		if(*dbg)printf("%i-nn:",*k);
+		if(*dbg)Rprintf("%i-nn:",*k);
 		double *dists2_i = new double[pp->size()], *dists2_i2 = new double[pp->size()];
 		for(i=0;i<pp->size();i++) //for each point
 		if(inc[i])
@@ -273,11 +325,10 @@ void Graph::sg_knn()
 						nodelist[i].push_back(l+1);
 						break;
 					}
-
 		}
 	}
 	else{ //preprocessed
-		if(*dbg)printf("%i-nn (shrinking):",*k);
+		if(*dbg)Rprintf("%i-nn (shrinking):",*k);
 		double *dists2_i, *dists2_i2;
 		for(i=0;i<pp->size();i++) //for each point
 		if(inc[i])
@@ -285,12 +336,13 @@ void Graph::sg_knn()
 			node = new std::vector<int>;
 			dists2_i = new double [nodelist[i].size()];
 			dists2_i2 = new double [nodelist[i].size()];
-			mik = *k;
+			mink = *k;
 			if( (int) nodelist[i].size()<*k )
 			{
-				mik = nodelist[i].size();
-				printf("\n preprocessing R too small, not enough neighbours (point #%i)!!\n",i+1);
+				mink = nodelist[i].size();
+				Rprintf("\n preprocessing R too small, not enough neighbours (point #%i)!!\n",i+1);
 			}
+
 			for(l=0;l< (int) nodelist[i].size();l++)
 			{
 				j = nodelist[i][l]-1;
@@ -298,8 +350,7 @@ void Graph::sg_knn()
 				dists2_i[l]=dists2_i2[l];
 			}
 			qsort( dists2_i, nodelist[i].size() , sizeof(double),compare_doubles); // sort distances, rising
-
-			for(j=0;j< mik;j++) // find the k nearest
+			for(j=0; j<mink ;j++) // find the k nearest
 				for(l=0;l< (int) nodelist[i].size();l++)
 					if( dists2_i[j] == dists2_i2[l] ) //with distance comparison
 					{
@@ -314,7 +365,7 @@ void Graph::sg_knn()
 		}
 	}
 	mdeg = kk;
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" Ok.");
 }
 
 void Graph::sg_shrink_knn()
@@ -329,13 +380,13 @@ void Graph::sg_shrink_knn()
 void Graph::sg_gabriel()
 {
 	int kk = (int) par[0];
-	if(*dbg & (kk>0) )printf("%i-",kk);
-	if(*dbg)printf("Gabriel:");
+	if(*dbg & (kk>0) )Rprintf("%i-",kk);
+	if(*dbg)Rprintf("Gabriel:");
 	int i,j,k, empty,m,l,h;
 	double x0,y0,R2, d;
 	std::vector<int> *node;
 
-	if(*this->prepR == 0) // no preprocessing done,a heavy looping
+	if(preEdges == 0) // no preprocessing done,a heavy looping
 	  for(i=0;i<(pp->size()-1);i++)
 	  {
 		  for(j=i+1;j<pp->size();j++)
@@ -365,43 +416,46 @@ void Graph::sg_gabriel()
 		  }
 	  }
 	else{ // preprocessed: nodelist has the restricted neighbourhoods to look trough
-		if(*dbg)printf("(prepd): ");
+		if(*dbg)Rprintf("(prepd): ");
 		for(i = 0 ; i< pp->size() ;  i++)
 		{
-			node = new std::vector<int>;
-			for( l=0 ; l < (int) this->nodelist[i].size(); l++ )
+			if(inc[i])
 			{
-				j = this->nodelist[i][l]-1;
-				x0 = fabs(this->pp->getX(&i)-this->pp->getX(&j))/2.0+fmin(this->pp->getX(&i),this->pp->getX(&j));
-				y0 = fabs(this->pp->getY(&i)-this->pp->getY(&j))/2.0+fmin(this->pp->getY(&i),this->pp->getY(&j));
-				R2 = (pow(this->pp->getX(&i)-this->pp->getX(&j),2) + pow(this->pp->getY(&i)-this->pp->getY(&j),2) )/4.0;
-				empty = 1+kk;
-				for(m=0; m <(int) this->nodelist[i].size();m++) // the small ball is included in the preprocessing ball
+				node = new std::vector<int>;
+				for( l=0 ; l < (int) this->nodelist[i].size(); l++ )
 				{
-					k =  (int) this->nodelist[i][m]-1;
-					if(k != i)
-						if( k != j)
-						{
-							d = pow(x0-pp->getX(&k),2) + pow(y0-pp->getY(&k),2);
-							if( d<R2 )
+					j = this->nodelist[i][l]-1;
+					x0 = fabs(this->pp->getX(&i)-this->pp->getX(&j))/2.0+fmin(this->pp->getX(&i),this->pp->getX(&j));
+					y0 = fabs(this->pp->getY(&i)-this->pp->getY(&j))/2.0+fmin(this->pp->getY(&i),this->pp->getY(&j));
+					R2 = (pow(this->pp->getX(&i)-this->pp->getX(&j),2) + pow(this->pp->getY(&i)-this->pp->getY(&j),2) )/4.0;
+					empty = 1+kk;
+					for(m=0; m <(int) this->nodelist[i].size();m++) // the small ball is included in the preprocessing ball
+					{
+						k =  (int) this->nodelist[i][m]-1;
+						if(k != i)
+							if( k != j)
 							{
-								empty = empty - 1;
-								if(empty == 0) break;
+								d = pow(x0-pp->getX(&k),2) + pow(y0-pp->getY(&k),2);
+								if( d<R2 )
+								{
+									empty = empty - 1;
+									if(empty == 0) break;
+								}
 							}
-						}
-				}
-				if(empty)
-				{
-					node->push_back(j+1);
+					}
+					if(empty)
+					{
+						node->push_back(j+1);
+					}
 				}
+				nodelist[i].clear();nodelist[i].resize(0);
+				for(h=0;h<(int)node->size();h++) nodelist[i].push_back(node->at(h));
+				delete node;
 			}
-			nodelist[i].clear();nodelist[i].resize(0);
-			for(h=0;h<(int)node->size();h++) nodelist[i].push_back(node->at(h));
-			delete node;
 		}
 	}
 	mdeg = 4;
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" Ok.");
 }
 
 /********************************************************************************************/
@@ -410,12 +464,12 @@ void Graph::sg_delaunay()
 //Naive algorithm, checks the interiors of triangle circumcircles.
 //For 2D patterns
 
-	if(*dbg)printf("Delaunay: ");
+	if(*dbg)Rprintf("Delaunay: ");
 	int i,j,k,l,h;
 	std::vector<int> *node;
-	if(*this->prepR==0) // no preprocessing done, heavy looping
+	if(preEdges==0) // no preprocessing done, heavy looping
 	{
-		if(*dbg)printf("(raw):");
+		if(*dbg)Rprintf("(raw):");
 		for(i = 0 ; i< pp->size()-2 ; i++ )
 			for(j = i+1 ; j < pp->size()-1 ; j++ )
 				for(k = j+1 ; k < pp->size() ; k++ )
@@ -427,37 +481,40 @@ void Graph::sg_delaunay()
 					}
 	}
 	else{ // preprocessed: nodelist has the restricted neighbourhoods to look trough for triangles
-		if(*dbg)printf("(prepd): ");
+		if(*dbg)Rprintf("(prepd): ");
 		for(i = 0 ; i< pp->size() ;  i++)
 		{
-			node = new std::vector<int>;
-			for( l=0 ; l < (int)nodelist[i].size()-1; l++ )
+			if(inc[i])
 			{
-				j = nodelist[i][l]-1;
-				for(h=l+1; h < (int)nodelist[i].size();h++ )
+				node = new std::vector<int>;
+				for( l=0 ; l < (int)nodelist[i].size()-1; l++ )
 				{
-					k = nodelist[i][h]-1;
-					if( pp->Empty(&i, &j, &k) )
+					j = nodelist[i][l]-1;
+					for(h=l+1; h < (int)nodelist[i].size();h++ )
 					{
-						node->push_back(j+1);
-						node->push_back(k+1);
+						k = nodelist[i][h]-1;
+						if( pp->EmptyConstrained(&i, &j, &k, &nodelist.at(i)) )
+						{
+							node->push_back(j+1);
+							node->push_back(k+1);
+						}
 					}
 				}
+				nodelist[i].clear();nodelist[i].resize(0);
+				for(h=0;h<(int)node->size();h++) nodelist[i].push_back((*node).at(h));
+				delete node;
 			}
-			nodelist[i].clear();nodelist[i].resize(0);
-			for(h=0;h<(int)node->size();h++) nodelist[i].push_back((*node).at(h));
-			delete node;
 		}
 		this->remove_duplicates();
 	}
 	mdeg = 6;
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" Ok.");
 
 }
 /********************************************************************************************/
 void Graph::sg_MST()
 {
-  if(*this->dbg) printf("MST:");
+  if(*this->dbg) Rprintf("MST:");
   int i,j,k=0,l=0,zz,k0=0,l0=0;
   int *done = new int[pp->size()],dn;
   double apu0,apu1,apu2;
@@ -495,29 +552,29 @@ void Graph::sg_MST()
     left--;
     this->nodelist[l].push_back(k+1);
   }
-  if(*this->dbg)printf(" Ok.");
+  if(*this->dbg)Rprintf(" Ok.");
 }
 /********************************************************************************************/
 void Graph::sg_markcross()
 {
-	if(*dbg)printf("Markcross: ");
+	if(*dbg)Rprintf("Markcross: ");
 	int i,j;
 	double dist;
 	for(i=0;i<(pp->size()-1);i++)
 		for(j=i+1;j<pp->size();j++)
 		{
 			dist = pp->getDist(&i, &j);
-			if(dist< pp->getMass(&i)+pp->getMass(&j)){
+			if(dist< (pp->getMass(&i)+pp->getMass(&j))){
 				nodelist[i].push_back(j+1);
 				nodelist[j].push_back(i+1);
 			}
 		}
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" Ok.");
 }
 /********************************************************************************************/
 void Graph::sg_SIG()
 {
-	if(*dbg)printf("Spheres-of-Influence:");
+	if(*dbg)Rprintf("Spheres-of-Influence:");
 	int i,j,dbg0=*dbg;
 	double dist;
 	for(i=0;i<pp->size();i++)
@@ -525,17 +582,17 @@ void Graph::sg_SIG()
 		dist = MAX_DOUBLE;
 		for(j=0;j<pp->size();j++)
 			if(i!=j) dist = fmin(dist, pp->getDist(&i, &j));
-		pp->setMass(&i,dist);
+		pp->setMass(&i,&dist);
 	}
 	*dbg=0;
 	sg_markcross();
 	*dbg=dbg0;
-	if(*dbg)printf(" Ok.");
+	if(*dbg)Rprintf(" Ok.");
 }
 /********************************************************************************************/
 void Graph::sg_RST()
 {
-  if(*dbg) printf("Radial Spanning Tree (o=(%f,%f,%f)): ",par[0],par[1],par[2]);
+  if(*dbg) Rprintf("Radial Spanning Tree (o=(%f,%f,%f)): ",par[0],par[1],par[2]);
   nodelist.resize(pp->size()-1);
   int i,j,k,foc_i=pp->size()-1;
   double apu0,apu1,apu2,apu3;
@@ -563,12 +620,12 @@ void Graph::sg_RST()
     }
     if(k>-1) addNew(k,i+1);//e[k*(*n)+i] = 1;
   }
-  if(*dbg) printf(" Ok.");
+  if(*dbg) Rprintf(" Ok.");
 }
 /********************************************************************************************/
 void Graph::sg_RNG()
 {
-	if(*dbg) printf("Relative neighbourhood: ");
+	if(*dbg) Rprintf("Relative neighbourhood: ");
 	int i,j,k,isempty;
     for(i=0;i<(pp->size()-1);i++)
     {
@@ -587,25 +644,25 @@ void Graph::sg_RNG()
         	}
         }
     }
-    if(*dbg) printf(" Ok.");
+    if(*dbg) Rprintf(" Ok.");
 }
 /********************************************************************************************/
 void Graph::sg_CCC()
 {
 	double m=MAX_DOUBLE, mm = -MAX_DOUBLE, apu;
-	if(*dbg) printf("Class Cover Catch for type=%i: ",(int)par[0]);
+	if(*dbg) Rprintf("Class Cover Catch for type=%i: ",(int)par[0]);
 	int i,j, type0=(int)par[0];
 	for(i=0; i<pp->size();i++)
 	{
-		pp->setMass(&i,mm);
+		pp->setMass(&i,&mm);
 		if(pp->getT(&i)==type0)
 		{
-			pp->setMass(&i, m);
+			pp->setMass(&i, &m);
 			for(j=0;j<pp->size();j++)
 				if( (j!=i) & (pp->getT(&j)!=type0) )
 				{
 					apu = fmin(pp->getMass(&i),pp->getDist(&i, &j));
-					pp->setMass(&i, apu);
+					pp->setMass(&i, &apu);
 				}
 		}
 	}
@@ -616,7 +673,7 @@ void Graph::sg_CCC()
 					if(pp->getT(&j)==type0)
 						if(pp->getDist(&i, &j)< pp->getMass(&i))
 							addNew(i,j+1);
-	if(*dbg) printf(" Ok.");
+	if(*dbg) Rprintf(" Ok.");
 }
 /********************************************************************************************/
 double Attenuate(double r, double alpha)
@@ -626,7 +683,7 @@ double Attenuate(double r, double alpha)
 
 void Graph::sg_STIR()
 {
-	if(*dbg) printf("Signal-To-Noise-Ratio graph, noise=%f,alpha=%f,beta=%f,gamma=%f: ",par[0],par[1],par[2],par[3]);
+	if(*dbg) Rprintf("Signal-To-Noise-Ratio graph, noise=%f,alpha=%f,beta=%f,gamma=%f: ",par[0],par[1],par[2],par[3]);
 	int i,j;
 	double noise0 = par[0], alpha=par[1],beta=par[2],gamma=par[3], *noise = new double[pp->size()], sij,sji,s;
 	//first we compute the interference for each location including the sending transmitter
@@ -651,7 +708,7 @@ void Graph::sg_STIR()
 				addNew(j,i+1);
 			}
 		}
-	if(*dbg) printf(" Ok.");
+	if(*dbg) Rprintf(" Ok.");
 }
 
 
@@ -660,7 +717,7 @@ void Graph::sg_STIR()
 void Graph::sg_cut(double *R)
 {
 	int i,j,k, count=0;
-	if(*dbg)printf("Cutting the graph (R=%f):",*R);
+	if(*dbg)Rprintf("Cutting the graph (R=%f):",*R);
 	std::vector<int > *pnode;
 	for(i=0;i < pp->size();i++)
 	{
@@ -677,7 +734,7 @@ void Graph::sg_cut(double *R)
 		nodelist.at(i).swap(*pnode);
 		delete pnode;
 	}
-	if(*dbg)printf(" ok (%i edges cut). ",count);
+	if(*dbg)Rprintf(" ok (%i edges cut). ",count);
 }
 /********************************************************************************************/
 // prune branches less than lev hops long
@@ -689,14 +746,14 @@ void Graph::sg_prune(double *lev)
 	std::vector<int> branch, *pnode;
 	left.resize(0);
 	branch.resize(0);
-	if(*dbg)printf("Pruning the graph (level=%i):",level);
+	if(*dbg)Rprintf("Pruning the graph (level=%i):",level);
 
 	for(i=0; i < (int)nodelist.size(); i++ ) // get the leaves
 	{
 		if( (int)nodelist.at(i).size() == 1 )
 			left.push_back(i+1);
 	}
-	if(*dbg)printf("found %i leaves, pruning...",(int)left.size());
+	if(*dbg)Rprintf("found %i leaves, pruning...",(int)left.size());
 
 	while(!left.empty()) // go each branch trough starting from the leaf
 	{
@@ -721,7 +778,7 @@ void Graph::sg_prune(double *lev)
 //				if(j == branch.at(i)){notnew=1; break;}
 //			if(notnew)break;
 		}
-//		printf("leaf:%i, branch length: %i\n",left.back(),branch.size());
+//		Rprintf("leaf:%i, branch length: %i\n",left.back(),branch.size());
 		if((int)branch.size() <= level) // if short enough branch, cut it.
 		{
 			pnode = new std::vector<int>;
@@ -740,7 +797,7 @@ void Graph::sg_prune(double *lev)
 		branch.clear();
 		branch.resize(0);
 	}
-	if(*dbg)printf(" Ok (%i branches pruned).",count);
+	if(*dbg)Rprintf(" Ok (%i branches pruned).",count);
 }
 /********************************************************************************************/
 
